@@ -141,7 +141,7 @@ to provide credentials.
 
 I<Note that when you set the environment variable AWS_PROFILE, the
 order essentially is overridden and we'll look in your credential
-files (F<~/.aws/config>, F<~/.aws/credentials>) for your credentials.
+files (F<~/.aws/config>, F<~/.aws/credentials>) for your credentials.>
 
 =item file - Configuration Files
 
